Struct keyset_color::Color

source ·
pub struct Color(/* private fields */);
sRGB Color type.

Internally stores red, green, and blue components as f32.

Implementations

source

impl Color

source

pub const fn new(r: f32, g: f32, b: f32) -> Self

Creates a new Color value with the given red, green, and blue component values.

The components should be in the range 0.0..1.0 for a semantically valid colour, although this function does not perform any range checks.

source

pub const fn r(&self) -> f32

Returns the red component.

source

pub const fn g(&self) -> f32

Returns the green component.

source

pub const fn b(&self) -> f32

Returns the blue component.

source

pub fn iter(&self) -> impl Iterator<Item = &f32>

Returns an iterator over the colour’s components.

source

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut f32>

Returns an iterator that allows modifying the colour’s components.

Modified components should be in the range 0.0..1.0 for a semantically valid colour, although this function does not perform any range checks.

source

pub fn map(self, f: impl FnMut(f32) -> f32) -> Self

Applies the function f to each of the colour’s components.

The resulting components should be in the range 0.0..1.0 for a semantically valid colour, although this function does not perform any range checks.

source

pub fn as_rgb8(&self) -> (u8, u8, u8)

Returns a tuple containing the red, green, and blue components as u8.

source

pub fn as_rgb16(&self) -> (u16, u16, u16)

Returns a tuple containing the red, green, and blue components as u16.

source

pub fn from_rgb8((r, g, b): (u8, u8, u8)) -> Self

Creates a new Color from a tuple containing the red, green, and blue components as u8.

source

pub fn from_rgb16((r, g, b): (u16, u16, u16)) -> Self

Creates a new Color from a tuple containing the red, green, and blue components as u16.

source

pub const fn as_slice(&self) -> &[f32]

Returns a slice containing the red, green, and blue components of the colour.

source

pub fn as_mut_slice(&mut self) -> &mut [f32]

Returns a mutable slice containing the red, green, and blue components of the colour.

source

impl Color

source

pub fn lighter(self, val: f32) -> Self

Lightens the colour by a given amount.

val should be in the range 0.0..1.0 for a semantically valid factor, although this function does not perform any range checks.

source

pub fn darker(self, val: f32) -> Self

Darkens the colour by a given amount.

val should be in the range 0.0..1.0 for a semantically valid factor, although this function does not perform any range checks.

source

pub fn highlight(self, val: f32) -> Self

Either calls lighter or darker on the colour depending on its luminance.

val should be in the range 0.0..1.0 for a semantically valid factor, although this function does not perform any range checks.